@@ -423,13 +423,11 @@ def floats(
     if allow_nan is None:
         allow_nan = bool(min_value is None and max_value is None)
     elif allow_nan and (min_value is not None or max_value is not None):
-        raise InvalidArgument(
-            f"Cannot have allow_nan={allow_nan!r}, with min_value or max_value"
-        )
+        raise InvalidArgument(f"Cannot have {allow_nan=}, with min_value or max_value")
 
     if width not in (16, 32, 64):
         raise InvalidArgument(
-            f"Got width={width!r}, but the only valid values "
+            f"Got {width=}, but the only valid values "
             "are the integers 16, 32, and 64."
         )
 
@@ -472,7 +470,7 @@ def floats(
                 "writeup - and good luck!"
             )
         raise FloatingPointError(
-            f"Got allow_subnormal={allow_subnormal!r}, but we can't represent "
+            f"Got {allow_subnormal=}, but we can't represent "
             f"subnormal floats right now, in violation of the IEEE-754 floating-point "
             f"specification.  {ftz_msg}"
         )
@@ -488,18 +486,18 @@ def floats(
     if min_value != min_arg:
         raise InvalidArgument(
             f"min_value={min_arg!r} cannot be exactly represented as a float "
-            f"of width {width} - use min_value={min_value!r} instead."
+            f"of width {width} - use {min_value=} instead."
         )
     if max_value != max_arg:
         raise InvalidArgument(
             f"max_value={max_arg!r} cannot be exactly represented as a float "
-            f"of width {width} - use max_value={max_value!r} instead."
+            f"of width {width} - use {max_value=} instead."
         )
 
     if exclude_min and (min_value is None or min_value == math.inf):
-        raise InvalidArgument(f"Cannot exclude min_value={min_value!r}")
+        raise InvalidArgument(f"Cannot exclude {min_value=}")
     if exclude_max and (max_value is None or max_value == -math.inf):
-        raise InvalidArgument(f"Cannot exclude max_value={max_value!r}")
+        raise InvalidArgument(f"Cannot exclude {max_value=}")
 
     assumed_allow_subnormal = allow_subnormal is None or allow_subnormal
     if min_value is not None and (
@@ -543,7 +541,7 @@ def floats(
             "and max_value=%r" % (width, min_arg, max_arg)
         )
         if exclude_min or exclude_max:
-            msg += f", exclude_min={exclude_min!r} and exclude_max={exclude_max!r}"
+            msg += f", {exclude_min=} and {exclude_max=}"
         raise InvalidArgument(msg)
 
     if allow_infinity is None:
@@ -551,8 +549,7 @@ def floats(
     elif allow_infinity:
         if min_value is not None and max_value is not None:
             raise InvalidArgument(
-                f"Cannot have allow_infinity={allow_infinity!r}, "
-                "with both min_value and max_value"
+                f"Cannot have {allow_infinity=}, with both min_value and max_value"
             )
     elif min_value == math.inf:
         if min_arg == math.inf:
